@@ -6,14 +6,16 @@
 # python-cli is copyright (c) 2011 by the python-cli authors. See the
 # file "AUTHORS" for a complete overview.
 
+from cli import compat
+
 
 class Error(Exception):
     """Base class for python-cli errors."""
 
     def __init__(self, message=None, **kwargs):
         if message is None:
-            message = self.__doc___
-        super(Error, self).__init__(message)
+            message = self.__doc__
+        compat.super(Error, self).__init__(message)
         for key in kwargs:
             setattr(self, key, kwargs[key])
 
