@@ -13,16 +13,29 @@ from optparse import OptionParser
 from cli.object import create
 from cli.settings import Settings
 from cli.context import ExecutionContext
+from cli.command import *
 
 
-class TestExecutionContext(ExecutionContext):
+class TestContext(ExecutionContext):
 
+    name = 'cli-test'
     welcome = textwrap.dedent("""\
         Welcome to cli-test. This is a test driver for the python-cli.
         Type 'exit' to exit or 'help' for help.
         """)
     goodbye = 'Goodbye!'
 
+    def setup_commands(self):
+        """Add commands."""
+        self.add_command(SetCommand)
+        self.add_command(SaveCommand)
+        self.add_command(HelpCommand)
+        self.add_command(StatusCommand)
+        self.add_command(CdCommand)
+        self.add_command(ClearCommand)
+        self.add_command(PwdCommand)
+        self.add_command(ExitCommand)
+
 
 def main():
     """Test driver for python-cli."""
@@ -30,17 +43,24 @@ def main():
     parser.add_option('-f', '--filter', metavar='FILE',
                       help='execute commands from FILE')
     parser.add_option('-d', '--debug', action='store_true',
-                      help='enable debugging mode')
+                      default=False, help='enable debugging mode')
+    parser.add_option('-v', '--verbose', action='store_const',
+                      dest='verbosity', default=0, const=10,
+                      help='be verbose',)
     opts, args = parser.parse_args()
 
     if opts.filter:
         try:
-            sys.stdin = file(opts.filter)
+            cmdin = file(opts.filter)
         except IOError, e:
             sys.stderr.write('error: %s\n' % e.strerror)
             sys.exit(1)
+    else:
+        cmdin = sys.stdin
 
-    context = create(TestExecutionContext)
+    context = create(TestContext, cmdin)
+    context.settings['cli:debug'] = opts.debug
+    context.settings['cli:verbosity'] = opts.verbosity
 
     if len(args) == 0:
         context.execute_loop()
